@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,15 +26,10 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#endif
-
 #ifdef _MSC_VER
 #pragma hdrstop
 #endif
 
-// INCLUDE ---------------------------------------------------------------
-
 #include "xmlimprt.hxx"
 #include "xmlfilti.hxx"
 #include "document.hxx"
@@ -41,19 +37,15 @@
 #include "dpsdbtab.hxx"
 #include "attrib.hxx"
 
-#ifndef _SC_XMLCONVERTER_HXX
 #include "XMLConverter.hxx"
-#endif
 
 #include <bf_xmloff/nmspmap.hxx>
 namespace binfilter {
 
-//#include <com/sun/star/sheet/DataPilotFieldOrientation.hpp>
-
 using namespace ::com::sun::star;
 using namespace xmloff::token;
 
-//------------------------------------------------------------------
+using rtl::OUString;
 
 ScXMLDataPilotTablesContext::ScXMLDataPilotTablesContext( ScXMLImport& rImport,
                                       USHORT nPrfx,
@@ -1040,3 +1032,5 @@ void ScXMLDataPilotMemberContext::EndElement()
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
