@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -63,7 +64,6 @@
 #include <bf_svx/outlobj.hxx>
 #include <bf_svtools/saveopt.hxx>
 #include <comphelper/extract.hxx>
-#include <vos/xception.hxx>
 #include <i18npool/mslangid.hxx>
 #include <unotools/charclass.hxx>
 #include <comphelper/processfactory.hxx>
@@ -1356,3 +1356,5 @@ sal_Int32 SdDrawDocument::GetPrinterIndependentLayout (void)
     return mnPrinterIndependentLayout;
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
