@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,18 +26,12 @@
  *
  ************************************************************************/
 
-#ifndef _SVXIDS_HRC
 #include <bf_svx/svxids.hrc>
-#endif
 
 
-#ifndef _RTL_USTRBUF_HXX_
 #include <rtl/ustrbuf.hxx>
-#endif
 
-#ifndef _SD_UNOKYWDS_HXX_
 #include "unokywds.hxx"
-#endif
 
 #include <vector>
 
@@ -942,3 +937,5 @@ void FrameView::WriteUserDataSequence ( ::com::sun::star::uno::Sequence < ::com:
      }
 }
 } //namespace binfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
